@@ -38,14 +38,6 @@
 #include "gradereferencewidget.h"
 
 
-// ----------------------------------------------------------------
-
-static int randInt(int low, int high)
-{
-    // Random number between low and high
-    return qrand() % ((high + 1) - low) + low;
-}
-
 // ================================================================
 //                         class Dashboard
 
@@ -213,7 +205,6 @@ void Dashboard::populateGrid()
 
         QUrl  url(QUrl::fromLocalFile(urlString));
         Collection *collection = new Collection(&url, this);
-        collection->close(); // We just want to look at it, not own it, so release the lock.
 
         WordCount dueWords;
 	int percentageCompleted = dueWords.percentageCompleted();
